@@ -65,13 +65,15 @@ void		camel_ews_utils_sync_deleted_items
 void		camel_ews_utils_sync_created_items
 						(CamelEwsFolder *ews_folder,
 						 EEwsConnection *cnc,
-						 GSList *items_created);
+						 GSList *items_created,
+						 GCancellable *cancellable);
 void		camel_ews_utils_sync_updated_items
 						(CamelEwsFolder *ews_folder,
 						 GSList *items_updated);
 void		ews_utils_replace_server_user_flags
 						(ESoapMessage *msg,
 						 CamelEwsMessageInfo *mi);
+gchar *		camel_ews_utils_get_host_name	(CamelSettings *settings);
 
 G_END_DECLS
 
